@@ -1,6 +1,4 @@
 #![allow(clippy::integer_arithmetic)]
-pub use solana_core::test_validator;
-pub use solana_gossip::cluster_info::MINIMUM_VALIDATOR_PORT_RANGE_WIDTH;
 use {
     console::style,
     fd_lock::{FdLock, FdLockGuard},
@@ -13,6 +11,9 @@ use {
         thread::JoinHandle,
     },
 };
+pub use {
+    solana_core::test_validator, solana_gossip::cluster_info::MINIMUM_VALIDATOR_PORT_RANGE_WIDTH,
+};
 
 pub mod admin_rpc_service;
 pub mod dashboard;
